summaryrefslogtreecommitdiffstats
path: root/kword/KWFrameView.h
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWFrameView.h')
-rw-r--r--kword/KWFrameView.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/kword/KWFrameView.h b/kword/KWFrameView.h
index 85e6981d..d4dcabde 100644
--- a/kword/KWFrameView.h
+++ b/kword/KWFrameView.h
@@ -28,7 +28,7 @@ class KoZoomHandler;
class KoPoint;
class KActionSeparator;
class KAction;
-class QPopupMenu;
+class TQPopupMenu;
/**
* This base class is an interface for Policies used in the KWFrameView.
@@ -38,19 +38,19 @@ public:
/** Constructor */
FramePolicy(KWFrameView *view);
/**
* Return the MouseMeaning enum value for the parent view.
* @param point the point where the mouse is hovering.
- * @param keyState the bitmask of keys that are pressed. Same as Event::state();
+ * @param keyState the bittqmask of keys that are pressed. Same as Event::state();
*/
virtual MouseMeaning mouseMeaning( const KoPoint &point, int keyState ) = 0;
/**
* Return a fully initialized popup for the context of frame at @p point
* @param point the point where the mouse is hovering.
* @param view the parent view widget
*/
- virtual QPopupMenu* createPopup( const KoPoint &point, KWView *view ) = 0;
+ virtual TQPopupMenu* createPopup( const KoPoint &point, KWView *view ) = 0;
/**
* Override this method to do more than select the parent frame-view
*/
virtual void setSelected(MouseMeaning) { }
@@ -58,15 +58,15 @@ protected:
/**
* Shared method for all policies called when the border of the frame is clicked.
* @param point the point where the mouse is hovering.
- * @param keyState the bitmask of keys that are pressed. Same as Event::state();
+ * @param keyState the bittqmask of keys that are pressed. Same as Event::state();
*/
virtual MouseMeaning mouseMeaningOnBorder(const KoPoint &point, int keyState);
/**
* Shared method for all policies to add the 'set floating' action to a popup menu.
* @param view the parent view widget
* @param actionList the list of actions where the floating action should be added to
*/
- void addFloatingAction(KWView *view, QPtrList<KAction> &actionList);
+ void addFloatingAction(KWView *view, TQPtrList<KAction> &actionList);
KWFrameView *m_view;
KActionSeparator *m_separator;
@@ -83,10 +83,10 @@ class KWFrameView {
public:
/**
* Constructor
* @param parent the parent
* @param frame the frame this view represents.
*/
- KWFrameView(KWFrameViewManager *parent, KWFrame *frame);
+ KWFrameView(KWFrameViewManager *tqparent, KWFrame *frame);
virtual ~KWFrameView();
/// returns if this frameView is selected. A selected frame is shown differently on screen.
@@ -105,27 +105,27 @@ public:
/// returns if the @p point is on the border
bool isBorderHit(const KoPoint &point) const;
/// returns if the @p point is anywhere in te frame, if fuzzy is true; also a little outside
- bool contains(const KoPoint &point, bool fuzzy = true) const;
+ bool tqcontains(const KoPoint &point, bool fuzzy = true) const;
/**
* Return the MouseMeaning enum value for the parent view.
* @param point the point where the mouse is hovering.
- * @param keyState the bitmask of keys that are pressed. Same as Event::state();
+ * @param keyState the bittqmask of keys that are pressed. Same as Event::state();
*/
MouseMeaning mouseMeaning( const KoPoint &point, int keyState );
- /// Return the parent KWFrameViewManager this frameView belongs to
- KWFrameViewManager *parent() const { return m_manager; }
+ /// Return the tqparent KWFrameViewManager this frameView belongs to
+ KWFrameViewManager *tqparent() const { return m_manager; }
/**
* Show a context-sensitive popup menu based on the location of 'point'.
* @param point the point at which the mouse was clicked. The context is based on
* what is present at that location.
* @param popupPoint the point in the same coordinate system as the parent widget of
* where the popup menu should be located.
* @param view the parent widget for the popup.
*/
- void showPopup( const KoPoint &point, KWView *view, const QPoint &popupPoint) const;
+ void showPopup( const KoPoint &point, KWView *view, const TQPoint &popupPoint) const;
/**
* Paint view based items of the frameView, like selected state
@@ -134,11 +134,11 @@ public:
* @param zh the zoomHandler to convert from internal coordinates to view coordinates
* @param vm the current Viewmode.
*/
- void paintFrameAttributes(QPainter *painter, const QRect &crect, KWViewMode *vm, KoZoomHandler *zh);
+ void paintFrameAttributes(TQPainter *painter, const TQRect &crect, KWViewMode *vm, KoZoomHandler *zh);
private:
/**
* Helper method for isBorderHit() and contains()
* @param point the point
* @param borderOnly if true; exclude the range inside the frame
* @param fuzzy don't take all the coordinates too strict, allow for some margin
@@ -157,7 +157,7 @@ class TableFramePolicy : public FramePolicy {
public:
TableFramePolicy(KWFrameView *view);
MouseMeaning mouseMeaning( const KoPoint &point, int keyState );
- QPopupMenu* createPopup( const KoPoint &point, KWView *view );
+ TQPopupMenu* createPopup( const KoPoint &point, KWView *view );
void setSelected(MouseMeaning selectPolicy);
protected:
@@ -169,7 +169,7 @@ class PartFramePolicy : public FramePolicy {
public:
PartFramePolicy(KWFrameView *view);
MouseMeaning mouseMeaning( const KoPoint &point, int keyState );
- QPopupMenu* createPopup( const KoPoint &point, KWView *view );
+ TQPopupMenu* createPopup( const KoPoint &point, KWView *view );
};
/** A policy for Text Frames */
@@ -177,7 +177,7 @@ class TextFramePolicy : public FramePolicy {
public:
TextFramePolicy(KWFrameView *view);
MouseMeaning mouseMeaning( const KoPoint &point, int keyState );
- QPopupMenu* createPopup( const KoPoint &point, KWView *view );
+ TQPopupMenu* createPopup( const KoPoint &point, KWView *view );
};
/** A policy for Image (aka Picture) Frames */
@@ -185,6 +185,6 @@ class ImageFramePolicy : public FramePolicy {
public:
ImageFramePolicy(KWFrameView *view);
MouseMeaning mouseMeaning( const KoPoint &point, int keyState );
- QPopupMenu* createPopup( const KoPoint &point, KWView *view );
+ TQPopupMenu* createPopup( const KoPoint &point, KWView *view );
};
#endif
@@ -38,19 +38,19 @@ public:
FramePolicy(KWFrameView *view);
/**
- * Return the MouseMeaning enum value for the parent view.
+ * Return the MouseMeaning enum value for the tqparent view.
* @param point the point where the mouse is hovering.
@@ -38,19 +38,19 @@ public:
* Return a fully initialized popup for the context of frame at @p point
* @param point the point where the mouse is hovering.
- * @param view the parent view widget
+ * @param view the tqparent view widget
*/
@@ -38,19 +38,19 @@ public:
/**
- * Override this method to do more than select the parent frame-view
+ * Override this method to do more than select the tqparent frame-view
*/
virtual void setSelected(MouseMeaning) { }
@@ -58,15 +58,15 @@ protected:
/**
* Shared method for all policies to add the 'set floating' action to a popup menu.
- * @param view the parent view widget
+ * @param view the tqparent view widget
* @param actionList the list of actions where the floating action should be added to
*/
@@ -83,10 +83,10 @@ class KWFrameView {
/**
* Constructor
- * @param parent the parent
+ * @param tqparent the tqparent
* @param frame the frame this view represents.
*/
@@ -105,27 +105,27 @@ public:
/**
- * Return the MouseMeaning enum value for the parent view.
+ * Return the MouseMeaning enum value for the tqparent view.
* @param point the point where the mouse is hovering.
@@ -105,27 +105,27 @@ public:
* @param point the point at which the mouse was clicked. The context is based on
* what is present at that location.
- * @param popupPoint the point in the same coordinate system as the parent widget of
+ * @param popupPoint the point in the same coordinate system as the tqparent widget of
* where the popup menu should be located.
@@ -105,27 +105,27 @@ public:
* where the popup menu should be located.
- * @param view the parent widget for the popup.
+ * @param view the tqparent widget for the popup.
*/
@@ -134,11 +134,11 @@ public:
private:
/**
- * Helper method for isBorderHit() and contains()
+ * Helper method for isBorderHit() and tqcontains()
* @param point the point
* @param borderOnly if true; exclude the range inside the frame